@@ -15,11 +15,6 @@ Usage (module):
     import jc
     result = jc.parse('ifconfig', ifconfig_command_output)
 
-    or
-
-    import jc.parsers.ifconfig
-    result = jc.parsers.ifconfig.parse(ifconfig_command_output)
-
 Schema:
 
     [
